### -*- coding: utf-8 -*- ####################################################
##############################################################################
#
# Copyright (c) 2012 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################


# import standard packages

# import Zope3 interfaces

# import local interfaces

# import Zope3 packages
from zope.interface import Interface
from zope.schema import TextLine, Bool

# import local packages

from ztfy.thesaurus import _


class IThesaurusTermFieldIndex(Interface):
    """Thesaurus term field index interface"""

    include_parents = Bool(title=_("Include term parents into index values"),
                           default=False,
                           required=False)

    include_synonyms = Bool(title=_("Include term synonyms into index values"),
                            default=False,
                            required=False)


class IThesaurusTermsListFieldIndex(Interface):
    """Thesaurus terms list field index interface"""

    include_parents = Bool(title=_("Include term parents into index values"),
                           default=False,
                           required=False)

    include_synonyms = Bool(title=_("Include term synonyms into index values"),
                            default=False,
                            required=False)
